@@ -59,10 +59,20 @@ wxWindow *ChooseOnePanel::cMakeAnswerCtrl(::One::Screen *ocurrent) throw(Excepti
   Screen *current = dynamic_cast<Screen*>(ocurrent);
   wxASSERT(current != NULL);
 
+  int length = 10;
+  for(Screen::choice_iterator iter = current->choices.begin();
+      iter != current->choices.end();
+      ++iter)
+  {
+    if(iter->Length() > length)
+      length = iter->Length();
+  }
+
   // Preparing the wxListCtrl lc:
   wxListCtrl *lc = new wxListCtrl(this, ONEPANEL_ANSWERCTRL, wxDefaultPosition,
 				  wxDefaultSize, wxLC_REPORT | wxLC_NO_HEADER);
   lc->InsertColumn(0, "Answer"); // The header of the column will never be displayed.
+  lc->SetColumnWidth(0, length * lc->GetCharWidth() + 2);
   
   for(Screen::choice_iterator iter = current->choices.begin();
       iter != current->choices.end();
