@@ -42,10 +42,13 @@ try
   }
   catch(Exception &ex)
   {
-    throw NoisyException("Malformed item in room list: this "
-			 "module requires the attributes "
-			 "\"html_file\", \"button_text\" and "
-			 "\"button_help\".");
+    // It could mean that an intro is not wanted, or that there is an
+    // error in the room list. We throw a silent exception and let the
+    // derived class decide.
+    throw SilentException("Malformed item in room list: this "
+			  "module requires the attributes "
+			  "\"html_file\", \"button_text\" and "
+			  "\"button_help\".");
   }
 
   try
