@@ -37,7 +37,7 @@ public:
   
   virtual void EnterRoom() throw(Exception) = 0;
   
-private:
+protected:
   class EXPORT PanelCreator: public CommandProcessor
   {
   public:
