@@ -35,6 +35,21 @@
 #include "multsimpanel.h"
 #include "selfcorr.h"
 
+// A subpanel that only contains windows that do not accept focus.
+// It could for example be used to contain wxStaticText controls.
+class NoFocusPanel: public wxPanel
+{
+public:
+  NoFocusPanel(wxWindow *parent,
+	       wxWindowID id = -1,
+	       const wxPoint& pos = wxDefaultPosition,
+	       const wxSize& size = wxDefaultSize):
+    wxPanel(parent, id, pos, size, wxNO_BORDER)
+  {}
+
+  virtual bool AcceptsFocus() const  { return false; }
+};
+
 MultSimPanel::MultSimPanel(MultSim *ms, const wxExpr *expr)
                            throw(Exception) try:
   m_ms(ms),
@@ -82,14 +97,14 @@ try
     wxSizer *sz;
     for(int i = 0; i < m_ms->m_data->GetRows() * m_ms->m_data->GetColumns(); i++)
     {
-      pl = new wxPanel(this, -1);
+      pl = new NoFocusPanel(this, -1);
       st = new wxStaticText(pl, -1, "   " + m_ms->m_data->GetQuestion(i) + " ",
 			    wxDefaultPosition, wxDefaultSize, wxALIGN_RIGHT);
       sz = new wxBoxSizer(wxHORIZONTAL);
       if(m_ms->m_theme != NULL)
       {
 	st->SetBackgroundColour(m_ms->m_theme->GetTextBackground());
-	pl->SetBackgroundColour(m_ms->m_theme->GetTextBackground());
+      	pl->SetBackgroundColour(m_ms->m_theme->GetTextBackground());
 	st->SetForegroundColour(m_ms->m_theme->GetTextForeground());
 	sz->Add(st, 0, wxCENTRE, 0);
 	pl->SetSizerAndFit(sz);
@@ -171,6 +186,10 @@ void MultSimPanel::GiveOneFocus() throw()
       find_new = false;
     }
   }
+  if(wxWindow::FindFocus() == NULL)
+  {
+    find_new = true;
+  }
   if(find_new)
   {
     for(list<SelfCorrecting*>::iterator iter = m_sc.begin();
@@ -181,6 +200,7 @@ void MultSimPanel::GiveOneFocus() throw()
       {
 	if((*iter)->IsEditable())
 	{
+	  wxLogDebug("Setting focus");
 	  (*iter)->SetFocus();
 	  break;
 	}
